import { IFileSystemAccess } from './file-system-access';
/**
 * Returns FileSystemAccess, a shared singleton utility class to provide methods to access and work with the file system. This is used under the hood of all the file system apis in @nativescript/core and provided as a lower level convenience if needed.
 * @returns FileSystemAccess
 */
export declare function getFileAccess(): IFileSystemAccess;
export declare class FileSystemEntity {
    _path: string;
    _name: string;
    _extension: string;
    _locked: boolean;
    _lastModified: Date;
    _isKnown: boolean;
    get parent(): Folder;
    remove(): Promise<any>;
    removeSync(onError?: (error: any) => any): void;
    rename(newName: string): Promise<any>;
    renameSync(newName: string, onError?: (error: any) => any): void;
    get name(): string;
    get path(): string;
    get lastModified(): Date;
}
export declare enum AndroidDirectory {
    ALARMS = "alarms",
    AUDIOBOOKS = "audiobooks",
    DCIM = "dcim",
    DOCUMENTS = "documents",
    DOWNLOADS = "downloads",
    MOVIES = "movies",
    MUSIC = "music",
    NOTIFICATIONS = "notifications",
    PICTURES = "pictures",
    PODCASTS = "podcasts",
    RINGTONES = "ringtones",
    SCREENSHOTS = "screenshots"
}
declare class Android {
    createFile(options: {
        relativePath?: string;
        name: string;
        mime: string;
        directory: AndroidDirectory;
    }): File;
}
declare class iOS {
}
export declare class File extends FileSystemEntity {
    static get ios(): iOS;
    static get android(): Android;
    static fromPath(path: string, copy?: boolean): File;
    static exists(path: string): boolean;
    get extension(): string;
    get isLocked(): boolean;
    get size(): number;
    append(content: any): Promise<void>;
    appendSync(content: any, onError?: (error: any) => any): void;
    appendText(content: string, encoding?: string): Promise<any>;
    appendTextSync(content: string, onError?: (error: any) => any, encoding?: string): void;
    copy(dest: string): Promise<boolean>;
    copySync(dest: string, onError?: (error: any) => any): any;
    read(): Promise<any>;
    readSync(onError?: (error: any) => any): any;
    write(content: any): Promise<void>;
    writeSync(content: any, onError?: (error: any) => any): void;
    readText(encoding?: string): Promise<string>;
    readTextSync(onError?: (error: any) => any, encoding?: string): string;
    writeText(content: string, encoding?: string): Promise<any>;
    writeTextSync(content: string, onError?: (error: any) => any, encoding?: string): void;
    _checkAccess(): void;
}
export declare class Folder extends FileSystemEntity {
    static fromPath(path: string): Folder;
    static exists(path: string): boolean;
    contains(name: string): boolean;
    clear(): Promise<any>;
    clearSync(onError?: (error: any) => void): void;
    get isKnown(): boolean;
    getFile(name: string): File;
    getFolder(name: string): Folder;
    getEntities(): Promise<Array<FileSystemEntity>>;
    getEntitiesSync(onError?: (error: any) => any): Array<FileSystemEntity>;
    eachEntity(onEntity: (entity: FileSystemEntity) => boolean): void;
}
export declare namespace knownFolders {
    function documents(): Folder;
    function externalDocuments(): Folder;
    function temp(): Folder;
    function currentApp(): Folder;
    namespace ios {
        function library(): Folder;
        function developer(): Folder;
        function desktop(): Folder;
        function downloads(): Folder;
        function movies(): Folder;
        function music(): Folder;
        function pictures(): Folder;
        function sharedPublic(): Folder;
    }
}
export declare namespace path {
    function normalize(path: string): string;
    function join(...paths: string[]): string;
    const separator: string;
}
export {};
